# File: yt_fetcher.py
import sys
import json
import yt_dlp

def get_youtube_data(video_url):
    ydl_opts = {
        'quiet': True,
        'no_warnings': True,
        'skip_download': True,
        'forcejson': True,
        'format': 'bestvideo+bestaudio/best'
    }

    with yt_dlp.YoutubeDL(ydl_opts) as ydl:
        info = ydl.extract_info(video_url, download=False)

        formats = info.get('formats', [])
        processed_formats = []

        for fmt in formats:
            if not fmt.get('url'):
                continue
            processed_formats.append({
                "itag": fmt.get("format_id"),
                "url": fmt.get("url"),
                "mimeType": fmt.get("mime_type") or fmt.get("ext"),
                "qualityLabel": fmt.get("format_note") or fmt.get("quality_label"),
                "audioQuality": fmt.get("audio_quality"),
                "bitrate": fmt.get("bitrate"),
                "width": fmt.get("width"),
                "height": fmt.get("height")
            })

        data = {
            "status": "OK",
            "id": info.get("id"),
            "title": info.get("title"),
            "lengthSeconds": str(info.get("duration")),
            "keywords": info.get("tags", []),
            "channelTitle": info.get("channel"),
            "channelId": info.get("channel_id"),
            "description": info.get("description"),
            "thumbnail": info.get("thumbnails", []),
            "viewCount": info.get("view_count"),
            "isPrivate": info.get("is_private", False),
            "category": info.get("categories")[0] if info.get("categories") else "",
            "publishDate": info.get("upload_date"),
            "formats": processed_formats
        }

        print(json.dumps(data))

if __name__ == "__main__":
    try:
        get_youtube_data(sys.argv[1])
    except Exception as e:
        print(json.dumps({"status": "error", "error": str(e)}))
